import React, { useState, useEffect } from 'react';
import logo from './LOGO.PNG.png';
import { Coins, Menu, X } from 'lucide-react';

export default function Navbar() {
  const [isScrolled, setIsScrolled] = useState(false);
  const [isMobileMenuOpen, setIsMobileMenuOpen] = useState(false);

  useEffect(() => {
    const handleScroll = () => {
      setIsScrolled(window.scrollY > 20);
    };
    window.addEventListener('scroll', handleScroll);
    return () => window.removeEventListener('scroll', handleScroll);
  }, []);

  return (
    <nav className={`fixed w-full z-50 transition-all duration-300 ${
      isScrolled ? 'bg-gray-900/90 backdrop-blur-lg shadow-lg' : 'bg-transparent'
    }`}>
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
        <div className="flex items-center justify-between h-20">
          <div className="flex items-center">
            <div className="flex items-center gap-2 hover:scale-105 transition-transform">
              <img src={logo} alt="Dvine Live Logo" className="h-8 w-8" />
              <span className="text-xl font-bold bg-gradient-to-r from-blue-500 to-purple-600 bg-clip-text text-transparent">
                Dvine Live
              </span>
            </div>
          </div>

          {/* Desktop Menu */}
          <div className="hidden md:block">
            <div className="flex items-center gap-6">
              <a href="#about" className="text-gray-300 hover:text-blue-500 transition-colors">About</a>
              <a href="#plans" className="text-gray-300 hover:text-blue-500 transition-colors">Plans</a>
              <a href="#how-it-works" className="text-gray-300 hover:text-blue-500 transition-colors">How It Works</a>
              <a href="#security" className="text-gray-300 hover:text-blue-500 transition-colors">Security</a>
              <a href="#roadmap" className="text-gray-300 hover:text-blue-500 transition-colors">Roadmap</a>
              <button className="ml-4 px-6 py-2.5 rounded-full bg-gradient-to-r from-blue-600 to-purple-600 hover:from-blue-700 hover:to-purple-700 text-white font-medium transition-all duration-300 hover:scale-105 hover:shadow-lg hover:shadow-blue-500/25">
                Join Now
              </button>
            </div>
          </div>

          {/* Mobile Menu Button */}
          <div className="md:hidden">
            <button
              onClick={() => setIsMobileMenuOpen(!isMobileMenuOpen)}
              className="text-gray-300 hover:text-white"
            >
              {isMobileMenuOpen ? <X size={24} /> : <Menu size={24} />}
            </button>
          </div>
        </div>

        {/* Mobile Menu */}
        {isMobileMenuOpen && (
          <div className="md:hidden">
            <div className="px-2 pt-2 pb-3 space-y-1 bg-gray-900/95 backdrop-blur-lg rounded-2xl mt-2 border border-gray-800">
              <a href="#about" className="block px-3 py-2 text-gray-300 hover:text-blue-500 transition-colors">About</a>
              <a href="#plans" className="block px-3 py-2 text-gray-300 hover:text-blue-500 transition-colors">Plans</a>
              <a href="#how-it-works" className="block px-3 py-2 text-gray-300 hover:text-blue-500 transition-colors">How It Works</a>
              <a href="#security" className="block px-3 py-2 text-gray-300 hover:text-blue-500 transition-colors">Security</a>
              <a href="#roadmap" className="block px-3 py-2 text-gray-300 hover:text-blue-500 transition-colors">Roadmap</a>
              <button className="w-full mt-2 px-6 py-2.5 rounded-full bg-gradient-to-r from-blue-600 to-purple-600 hover:from-blue-700 hover:to-purple-700 text-white font-medium transition-all duration-300">
                Join Now
              </button>
            </div>
          </div>
        )}
      </div>
    </nav>
  );
}