import React, { useEffect, useState } from 'react';
import { ArrowRight, Users, Clock, Award } from 'lucide-react';

export default function Hero() {
  const [count1, setCount1] = useState(0);
  const [count2, setCount2] = useState(0);
  const [count3, setCount3] = useState(0);

  useEffect(() => {
    const duration = 2000; // 2 seconds
    const interval = 20; // Update every 20ms
    const steps = duration / interval;
    
    const counter1 = setInterval(() => {
      setCount1(prev => prev < 10000 ? prev + Math.ceil(10000 / steps) : 10000);
    }, interval);
    
    const counter2 = setInterval(() => {
      setCount2(prev => prev < 5000 ? prev + Math.ceil(5000 / steps) : 5000);
    }, interval);
    
    const counter3 = setInterval(() => {
      setCount3(prev => prev < 1000000 ? prev + Math.ceil(1000000 / steps) : 1000000);
    }, interval);

    return () => {
      clearInterval(counter1);
      clearInterval(counter2);
      clearInterval(counter3);
    };
  }, []);

  return (
    <div className="relative min-h-screen flex items-center justify-center overflow-hidden pt-20">
      <div className="absolute inset-0">
        <div className="absolute inset-0 bg-gradient-to-b from-blue-900/20 via-gray-900 to-gray-900"></div>
        <div className="absolute inset-0 bg-[url('https://images.unsplash.com/photo-1639762681485-074b7f938ba0?auto=format&fit=crop&q=80')] bg-cover bg-center bg-no-repeat opacity-20"></div>
        <div className="absolute inset-0 bg-[radial-gradient(circle_at_center,rgba(0,0,0,0)_0%,rgba(0,0,0,0.8)_100%)]"></div>
      </div>
      
      <div className="relative max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 text-center">
        <div className="space-y-8">
          <h1 className="text-5xl md:text-7xl font-bold mb-8 gradient-text animate-fade-in">
            The Future of Decentralized Earnings
          </h1>
          <p className="text-xl md:text-2xl text-gray-300 mb-12 max-w-3xl mx-auto animate-fade-in" style={{animationDelay: '0.2s'}}>
            Earn sustainably with Smart Contracts on opBNB. Join the next generation of decentralized finance.
          </p>
          
          <div className="grid md:grid-cols-3 gap-8 mb-16">
            <div className="glass-card p-8 animate-float" style={{animationDelay: '0s'}}>
              <Users className="w-8 h-8 text-blue-500 mb-4 mx-auto" />
              <div className="text-3xl font-bold text-blue-500">{count1.toLocaleString()}+</div>
              <div className="text-gray-400">Active Users</div>
            </div>
            <div className="glass-card p-8 animate-float" style={{animationDelay: '0.2s'}}>
              <Clock className="w-8 h-8 text-purple-500 mb-4 mx-auto" />
              <div className="text-3xl font-bold text-purple-500">{count2.toLocaleString()}+</div>
              <div className="text-gray-400">Daily Transactions</div>
            </div>
            <div className="glass-card p-8 animate-float" style={{animationDelay: '0.4s'}}>
              <Award className="w-8 h-8 text-pink-500 mb-4 mx-auto" />
              <div className="text-3xl font-bold text-pink-500">${count3.toLocaleString()}</div>
              <div className="text-gray-400">Total Rewards Paid</div>
            </div>
          </div>
          
          <div className="flex flex-col md:flex-row items-center justify-center gap-8 mb-16">
            <div className="glass-card p-8 hover-glow">
              <div className="text-3xl font-bold text-blue-500">$10</div>
              <div className="text-xl">Earn up to $358</div>
            </div>
            <div className="glass-card p-8 hover-glow">
              <div className="text-3xl font-bold text-purple-500">$25</div>
              <div className="text-xl">Earn up to $895</div>
            </div>
          </div>
          
          <button className="px-8 py-4 rounded-full bg-gradient-to-r from-blue-600 to-purple-600 hover:from-blue-700 hover:to-purple-700 text-white text-lg font-medium flex items-center gap-2 mx-auto transition-all duration-300 hover:transform hover:scale-105 hover:shadow-lg hover:shadow-blue-500/25 animate-fade-in" style={{animationDelay: '0.6s'}}>
            Get Started Now
            <ArrowRight className="w-5 h-5" />
          </button>
        </div>
      </div>
      
      <div className="absolute bottom-0 left-0 right-0 h-32 bg-gradient-to-t from-gray-900 to-transparent"></div>
    </div>
  );
}