import React from 'react';
import { ArrowRight, Check, Star } from 'lucide-react';

export default function Plans() {
  const plans = [
    {
      name: "Starter Plan",
      price: "$10",
      earning: "$358",
      features: [
        "Instant activation on opBNB",
        "Multi-level referral system",
        "24/7 Smart contract earnings",
        "Real-time dashboard tracking"
      ],
      delay: '0s',
      popular: false
    },
    {
      name: "Growth Plan",
      price: "$25",
      earning: "$895",
      features: [
        "Enhanced earning potential",
        "Priority withdrawal processing",
        "Advanced analytics dashboard",
        "VIP community access"
      ],
      delay: '0.2s',
      popular: true
    }
  ];

  return (
    <section id="plans" className="py-20 relative">
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
        <div className="text-center mb-16 animate-fade-in">
          <h2 className="text-4xl font-bold gradient-text">
            Investment Plans
          </h2>
          <p className="mt-4 text-gray-400 max-w-2xl mx-auto">
            Choose the perfect plan to start your decentralized earning journey
          </p>
        </div>

        <div className="grid md:grid-cols-2 gap-8 max-w-5xl mx-auto">
          {plans.map((plan, index) => (
            <div 
              key={index}
              className={`glass-card p-8 animate-fade-in relative ${
                plan.popular ? 'border-blue-500/50' : ''
              }`}
              style={{ animationDelay: plan.delay }}
            >
              {plan.popular && (
                <div className="absolute -top-4 left-1/2 transform -translate-x-1/2">
                  <div className="bg-gradient-to-r from-blue-600 to-purple-600 text-white px-4 py-1 rounded-full text-sm font-medium flex items-center gap-1">
                    <Star className="w-4 h-4" />
                    Most Popular
                  </div>
                </div>
              )}

              <div className="text-center">
                <h3 className="text-2xl font-bold mb-2 gradient-text">{plan.name}</h3>
                <div className="flex items-baseline justify-center gap-2 mb-6">
                  <span className="text-4xl font-bold text-blue-500">{plan.price}</span>
                  <span className="text-gray-400">investment</span>
                </div>
                <div className="mb-8">
                  <div className="text-sm text-gray-400">Potential earnings up to</div>
                  <div className="text-3xl font-bold bg-gradient-to-r from-purple-500 to-pink-500 bg-clip-text text-transparent">
                    {plan.earning}
                  </div>
                </div>
              </div>

              <ul className="space-y-4 mb-8">
                {plan.features.map((feature, featureIndex) => (
                  <li key={featureIndex} className="flex items-center gap-3">
                    <div className="flex-shrink-0 w-5 h-5 rounded-full bg-gradient-to-r from-blue-500 to-purple-500 flex items-center justify-center">
                      <Check className="w-3 h-3 text-white" />
                    </div>
                    <span className="text-gray-300">{feature}</span>
                  </li>
                ))}
              </ul>

              <button className="w-full px-6 py-3 rounded-lg bg-gradient-to-r from-blue-600 to-purple-600 hover:from-blue-700 hover:to-purple-700 text-white font-medium flex items-center justify-center gap-2 transition-all duration-300 hover:scale-105 hover:shadow-lg hover:shadow-blue-500/25">
                Get Started
                <ArrowRight className="w-5 h-5" />
              </button>
            </div>
          ))}
        </div>
      </div>
    </section>
  );
}